@@ -3,7 +3,7 @@ package FFI::C::Util;
 use strict;
 use warnings;
 use 5.008001;
-use Ref::Util qw( is_blessed_ref is_plain_arrayref is_plain_hashref is_ref );
+use Ref::Util qw( is_blessed_ref is_plain_arrayref is_plain_hashref is_ref is_blessed_hashref );
 use Sub::Identify ();
 use Carp ();
 use Class::Inspector;
@@ -12,7 +12,7 @@ use base qw( Exporter );
 our @EXPORT_OK = qw( perl_to_c c_to_perl take owned set_array_count );
 
 # ABSTRACT: Utility functions for dealing with structured C data
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub perl_to_c ($$)
@@ -79,7 +79,7 @@ sub c_to_perl ($)
 
       # get the value;
       my $value = $inst->$key;
-      $value = &c_to_perl($value) if is_blessed_ref $value;
+      $value = &c_to_perl($value) if is_blessed_hashref $value;
       $value = [@$value] if is_plain_arrayref $value;
       $h{$key} = $value;
     }
@@ -131,7 +131,7 @@ FFI::C::Util - Utility functions for dealing with structured C data
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
